export default {
  data() {
    return {
      isShowFull: true, //是否支持全屏
      prefixName: ''
    }
  },
  mounted() {
    /*//是否支持全屏
    this.isFullscreen();
    //监听全屏事件
    this.screenChange()*/
  },
  methods: {
    //是否支持全屏+判断浏览器前缀
    isFullscreen() {
      let fullscreenEnabled;
      // 判断浏览器前缀
      if (document.fullscreenEnabled) {
        fullscreenEnabled = document.fullscreenEnabled;
      } else if (document.webkitFullscreenEnabled) {
        fullscreenEnabled = document.webkitFullscreenEnabled;
        this.prefixName = 'webkit';
      } else if (document.mozFullScreenEnabled) {
        fullscreenEnabled = document.mozFullScreenEnabled;
        this.prefixName = 'moz';
      } else if (document.msFullscreenEnabled) {
        fullscreenEnabled = document.msFullscreenEnabled;
        this.prefixName = 'ms';
      }
      if (!fullscreenEnabled) {
        this.isShowFull = false;
      }
    },
    /**
     * @description: 需要全屏展示的元素
     * @param {String} element
     */
    Fullscreen(element) {
      const methodName =
        this.prefixName === ''
          ? 'requestFullscreen'
          : `${this.prefixName}RequestFullScreen`; // API前缀
      element[methodName](); // 调用全屏
    },
    //退出全屏
    exitFullscreen() {
      const methodName =
        this.prefixName === ''
          ? 'exitFullscreen'
          : `${this.prefixName}ExitFullscreen`; // API 前缀
      document[methodName](); // 调用
    },
    /**
     * @description: 检测有没有元素处于全屏状态
     * @return 布尔值
     */
    isElementFullScreen() {
      const fullscreenElement =
        document.fullscreenElement ||
        document.msFullscreenElement ||
        document.mozFullScreenElement ||
        document.webkitFullscreenElement; // 有前缀的f是大写，没前缀是小写
      //null 就是没有元素全屏;  没有全屏返回true
      return fullscreenElement === null;
    },
    //监听进入/离开全屏
    screenChange() {
      if (!this.isShowFull) return;
      const methodName = `on${this.prefixName}fullscreenchange`;
      document[methodName] = e => {
        this.isFull = this.isElementFullScreen();
        $store.commit('setFullscreen');
        if (this.isElementFullScreen()) {
          this.quitFull(e); // 离开全屏的回调
        } else {
          this.enterFull(e); // 进入全屏回调
        }
      };
    },
    //进入全屏回调
    enterFull() {},
    //退出全屏回调
    quitFull() {}
  },
  beforeDestroy() {
    if (!this.isShowFull) return;
    const methodName = `on${this.prefixName}fullscreenchange`;
    document[methodName] = null;
  }
}