import 'babel-polyfill';
import Promise from 'es6-promise'
Promise.polyfill()
import {lang, langConfig} from './langProcess';

import Vue from 'vue';
import ViewUI from 'view-design';
import VueRouter from 'vue-router';
import Vuex from 'vuex';
import App from './App.vue';
import Cookies from 'js-cookie';
import store from './vuex/index.js'
import 'view-design/dist/styles/iview.css';
import ElementUI from 'element-ui'
import 'element-ui/lib/theme-chalk/index.css'
import './tools/index.js'
import './axios.config.js'
import { routers, appRouter } from './router';
import filters from './filters.js'
import { system, routerEvent } from './index.js'
import axios from 'axios';

// import '../static/UE/ueditor.config.js'
// import '../static/UE/ueditor.all.min.js'
// import '../static/UE/lang/zh-cn/zh-cn.js'
// import '../static/UE/ueditor.parse.min.js'

import  VueQuillEditor from 'vue-quill-editor'//引入ue富文本组件vue-quill-editor
import 'quill/dist/quill.core.css'// require styles 引入样式
import 'quill/dist/quill.snow.css'
import 'quill/dist/quill.bubble.css'
Vue.config.devtools = process.env.API.devtools;
Vue.use(VueQuillEditor);

Vue.use(system, {
  app: {
    title: '通用开发平台',
    //配置主页显示内容
    // home: {
    //   "path": "feedback",
    //   "title": "建议反馈",
    //   "name": "feedback"
    // }
  },
  login: {
    hasCaptcha: false
  }
});

// 引入echarts
import echarts from 'echarts';

Vue.prototype.$echarts = echarts;

import VueI18n from 'vue-i18n';

Vue.use(VueRouter);
Vue.use(Vuex);
Vue.use(VueI18n);
Vue.use(ViewUI);
Vue.use(ElementUI)
// Vue.use(Tree);
// Vue.use(Select);
// Vue.use(Option);
// Vue.use(Tabs);
// Vue.use(TabPane);

Vue.prototype.ActionBarConfig = (config) => {
  $channel.$emit('ActionBarEvent', config);
}


for (let filter of filters) {
  Vue.filter(filter.name, filter.fn);
}

Vue.config.lang = lang;

// 多语言配置
Vue.locale('zh-CN', langConfig['zh-CN']);
Vue.locale('en-US', langConfig['en-US']);

// const i18n = new VueI18n({
//   locale: 'zh-CN',
//   messages: locales
// })

// 路由配置
const RouterConfig = {
  // mode: 'history',
  routes: routers
};

const router = new VueRouter(RouterConfig);

router.beforeEach((to, from, next) => {
  ViewUI.LoadingBar.start();
  routerEvent.beforeEach(to, from, next);
  ViewUI.LoadingBar.finish();
  $channel.$emit('RouterChangeBefore');
  $channel.$emit('ActionBarEvent', []);
  store.commit('clearLoading');
});

router.afterEach(() => {
  ViewUI.LoadingBar.finish();
  window.scrollTo(0, 0);
});

window.$app = new Vue({
  el: '#app',
  router: router,
  store: store,
  // i18n,
  render: h => h(App),
  // 没用到的代码
  // data: {
  //   currentPageName: ''
  // },
  // mounted() {
  //   this.currentPageName = this.$route.name;
  // },
  created() {
    if (!!sessionStorage.crctoken) {
      $axios.defaults.headers.crctoken = sessionStorage.crctoken
    } else {
      if (!!process.env.API.sso) {
        /*this.$Spin.show({
          render: (h) => {
            return h('div', [
              h('Icon', {
                'class': 'demo-spin-icon-load',
                props: {
                  type: 'load-c',
                  size: 18
                }
              }),
              h('div', '登录中...')
            ])
          }
        });*/
        axios.post(`${process.env.API.baseURL}/sys/ssologin`).then((response) => {
          //this.$Spin.hide();
          sessionStorage.crctoken = response.data.dataResult.crctoken;
          $axios.defaults.headers.crctoken = sessionStorage.crctoken
          this.$router.push({
            name: $store.getters.homePage.name
          });
        }).catch(err => {
          //this.$Spin.hide();
        });
      }
    }
    this.$store.commit('setTagsList', [...appRouter.children]);
    // axios.get(window.location.pathname + window.location.search).then((r) => {
    //   sessionStorage['OAM_REMOTE_USER'] = r.headers['date'] || '';
    //   sessionStorage.setItem('OAM_REMOTE_USER', r.headers['OAM_REMOTE_USER'] || '')
    //   if (!!r.headers['OAM_REMOTE_USER']) {
    //     this.$router.replace({
    //       name: 'transfers'
    //     })
    //   }
    // })
  },
  mounted() {

  }
});


window.$store = store;

window.$confirm = (text, vue) => {
  return new Promise((resolve) => {
    vue.$Modal.confirm({
      title: '操作提示',
      content: text,
      onOk: () => {
        resolve();
      },
      onCancel: () => {
        resolve();
      }
    });
  })
}
